from django import http
from django.views.generic import View

import requests


class Proxy(View):
    def get(self, request, *args, **kwargs):
        from pprint import pprint
        response = requests.get('http://localhost:3000' + request.path + '?' + request.GET.urlencode())
        ret = http.HttpResponse(
            content=bytes(response.content),
        )
        ret['Access-Control-Allow-Headers'] = 'http://localhost:8000'
        ret['Access-Control-Allow-Methods'] = 'OPTIONS, GET'
        ret['Access-Control-Allow-Origin'] = 'http://localhost:8000'
        ret['Access-Control-Allow-Method'] = 'http://localhost:8000'
        ret['Content-Type'] = response.headers['Content-Type']
        return ret



import os

import django12factor
globals().update(django12factor.factorise())

'''

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
'''

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    'djnext_example',  # load layout template
    'djnext_example.artist',  # example app in this directory

    'djnext',  # for isomorphic code love

    'crudlfap',  # for dev command
]

ROOT_URLCONF = 'djnext_example.urls'

TEMPLATES = [
    {
        'BACKEND': 'djnext.Backend',
    },
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'djnext_example.wsgi.application'

SECRET_KEY = os.environ.get('SECRET_KEY', 'notsecret')

STATIC_URL = '/static/'



from django.contrib.staticfiles import finders
from django.template import TemplateDoesNotExist, TemplateSyntaxError
from django.template.backends.base import BaseEngine
from django.template.backends.utils import csrf_input_lazy, csrf_token_lazy

import requests


class Backend(BaseEngine):
    # Name of the subdirectory containing the templates for this engine
    # inside an installed application.
    app_dirname = 'pages'

    def __init__(self, params):
        params = params.copy()
        options = params.pop('OPTIONS').copy()
        super().__init__(params)

    def from_string(self, template_code):
        try:
            return Template(code=template_code)
        except exc:
            raise TemplateSyntaxError(exc.args)

    def get_template(self, template_name):
        target = 'pages/' + template_name
        result = finders.find(target, all=True)
        if not result:
            raise TemplateDoesNotExist(exc.args, backend=self)
        return Template(path=result[0])
        '''
        try:
            return Template(self.engine.get_template(template_name))
        except foobar.TemplateNotFound as exc:
            raise TemplateDoesNotExist(exc.args, backend=self)
        except foobar.TemplateCompilationFailed as exc:
            raise TemplateSyntaxError(exc.args)
            '''


class Template:

    def __init__(self, path, code=None):
        print(path, code)
        self.path = path
        self.code = code

    def render(self, context=None, request=None):
        name = self.path.split('/')[-1][:-3]  # remove .js
        return requests.get('http://localhost:3000/' + name).content
